The basic idea of Long Nickels method is that the cash flows of a VC fund i.e.
contributions and distributions are invested in a stock market index and to
generate a net asset value (NAV) at the end of each period. The last NAV is
used to calculate the IRR and this IRR is the Long Nickels PME.

See also:
- `ln_pme_nav` function
- <https://en.wikipedia.org/wiki/Public_Market_Equivalent#Long-Nickels_PME>
- <https://blog.edda.co/advanced-fund-performance-methods-pme-direct-alpha/>
